meta-package-manager — Meta Package Manager 2.4.0 documentation

# meta-package-manager

- meta_package_manager package
  - Subpackages
    - meta_package_manager.bitbar package
      - Submodules
    - meta_package_manager.managers package
      - Submodules
    - meta_package_manager.tests package
      - Submodules
  - Submodules
    - meta_package_manager.base module
    - meta_package_manager.cli module
    - meta_package_manager.platform module
- setup module